@@ -67,9 +67,8 @@ import org.apache.tomcat.util.openssl.openssl_h_Compatibility;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
- * Implements a {@link SSLEngine} using
- * <a href="https://www.openssl.org/docs/crypto/BIO_s_bio.html#EXAMPLE">OpenSSL
- * BIO abstractions</a>.
+ * Implements a {@link SSLEngine} using <a href="https://www.openssl.org/docs/crypto/BIO_s_bio.html#EXAMPLE">OpenSSL BIO
+ * abstractions</a>.
  */
 public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolInfo {
 
@@ -87,8 +86,8 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
         availableCipherSuites.addAll(OpenSSLLibrary.findCiphers("ALL"));
         AVAILABLE_CIPHER_SUITES = Collections.unmodifiableSet(availableCipherSuites);
         IMPLEMENTED_PROTOCOLS_SET = Set.of(Constants.SSL_PROTO_SSLv2Hello, Constants.SSL_PROTO_SSLv2,
-            Constants.SSL_PROTO_SSLv3, Constants.SSL_PROTO_TLSv1, Constants.SSL_PROTO_TLSv1_1,
-            Constants.SSL_PROTO_TLSv1_2, Constants.SSL_PROTO_TLSv1_3);
+                Constants.SSL_PROTO_SSLv3, Constants.SSL_PROTO_TLSv1, Constants.SSL_PROTO_TLSv1_1,
+                Constants.SSL_PROTO_TLSv1_2, Constants.SSL_PROTO_TLSv1_3);
     }
 
     private static final int MAX_PLAINTEXT_LENGTH = 16 * 1024; // 2^14
@@ -106,7 +105,8 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
 
     private static final String INVALID_CIPHER = "SSL_NULL_WITH_NULL_NULL";
 
-    private static final ConcurrentHashMap<Long, EngineState> states = new ConcurrentHashMap<>();
+    private static final ConcurrentHashMap<Long,EngineState> states = new ConcurrentHashMap<>();
+
     private static EngineState getState(MemorySegment ssl) {
         return states.get(Long.valueOf(ssl.address()));
     }
@@ -116,9 +116,20 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
     private final Cleanable cleanable;
     private MemorySegment bufSegment;
 
-    private enum Accepted { NOT, IMPLICIT, EXPLICIT }
+    private enum Accepted {
+        NOT,
+        IMPLICIT,
+        EXPLICIT
+    }
+
     private Accepted accepted = Accepted.NOT;
-    private enum PHAState { NONE, START, COMPLETE }
+
+    private enum PHAState {
+        NONE,
+        START,
+        COMPLETE
+    }
+
     private boolean handshakeFinished;
     private int currentHandshake;
     private boolean receivedShutdown;
@@ -153,23 +164,18 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
     /**
      * Creates a new instance
      *
-     * @param sslCtx an OpenSSL {@code SSL_CTX} object
-     * @param fallbackApplicationProtocol the fallback application protocol
-     * @param clientMode {@code true} if this is used for clients, {@code false}
-     * otherwise
-     * @param sessionContext the {@link OpenSSLSessionContext} this
-     * {@link SSLEngine} belongs to.
-     * @param alpn {@code true} if alpn should be used, {@code false}
-     * otherwise
-     * @param initialized {@code true} if this instance gets its protocol,
-     * cipher and client verification from the {@code SSL_CTX} {@code sslCtx}
-     * @param certificateVerificationDepth Certificate verification depth
-     * @param certificateVerificationOptionalNoCA Skip CA verification in
-     *   optional mode
+     * @param sslCtx                              an OpenSSL {@code SSL_CTX} object
+     * @param fallbackApplicationProtocol         the fallback application protocol
+     * @param clientMode                          {@code true} if this is used for clients, {@code false} otherwise
+     * @param sessionContext                      the {@link OpenSSLSessionContext} this {@link SSLEngine} belongs to.
+     * @param alpn                                {@code true} if alpn should be used, {@code false} otherwise
+     * @param initialized                         {@code true} if this instance gets its protocol, cipher and client
+     *                                                verification from the {@code SSL_CTX} {@code sslCtx}
+     * @param certificateVerificationDepth        Certificate verification depth
+     * @param certificateVerificationOptionalNoCA Skip CA verification in optional mode
      */
-    OpenSSLEngine(Cleaner cleaner, MemorySegment sslCtx, String fallbackApplicationProtocol,
-            boolean clientMode, OpenSSLSessionContext sessionContext, boolean alpn,
-            boolean initialized, int certificateVerificationDepth,
+    OpenSSLEngine(Cleaner cleaner, MemorySegment sslCtx, String fallbackApplicationProtocol, boolean clientMode,
+            OpenSSLSessionContext sessionContext, boolean alpn, boolean initialized, int certificateVerificationDepth,
             boolean certificateVerificationOptionalNoCA, boolean noOcspCheck) {
         if (sslCtx == null) {
             throw new IllegalArgumentException(sm.getString("engine.noSSLContext"));
@@ -223,8 +229,8 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
     }
 
     /**
-     * Write plain text data to the OpenSSL internal BIO
-     * Calling this function with src.remaining == 0 is undefined.
+     * Write plain text data to the OpenSSL internal BIO Calling this function with src.remaining == 0 is undefined.
+     *
      * @throws SSLException if the OpenSSL error check fails
      */
     private int writePlaintextData(final MemorySegment ssl, final ByteBuffer src) throws SSLException {
@@ -247,6 +253,7 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
 
     /**
      * Write encrypted data to the OpenSSL network BIO.
+     *
      * @throws SSLException if the OpenSSL error check fails
      */
     private int writeEncryptedData(final MemorySegment networkBIO, final ByteBuffer src) throws SSLException {
@@ -269,6 +276,7 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
 
     /**
      * Read plain text data from the OpenSSL internal BIO
+     *
      * @throws SSLException if the OpenSSL error check fails
      */
     private int readPlaintextData(final MemorySegment ssl, final ByteBuffer dst) throws SSLException {
@@ -291,9 +299,11 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
 
     /**
      * Read encrypted data from the OpenSSL network BIO
+     *
      * @throws SSLException if the OpenSSL error check fails
      */
-    private int readEncryptedData(final MemorySegment networkBIO, final ByteBuffer dst, final int pending) throws SSLException {
+    private int readEncryptedData(final MemorySegment networkBIO, final ByteBuffer dst, final int pending)
+            throws SSLException {
         clearLastError();
         final int pos = dst.position();
         MemorySegment dstSegment = dst.isDirect() ? MemorySegment.ofBuffer(dst) : bufSegment;
@@ -311,10 +321,12 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
     }
 
     @Override
-    public synchronized SSLEngineResult wrap(final ByteBuffer[] srcs, final int offset, final int length, final ByteBuffer dst) throws SSLException {
+    public synchronized SSLEngineResult wrap(final ByteBuffer[] srcs, final int offset, final int length,
+            final ByteBuffer dst) throws SSLException {
         // Check to make sure the engine has not been closed
         if (destroyed) {
-            return new SSLEngineResult(SSLEngineResult.Status.CLOSED, SSLEngineResult.HandshakeStatus.NOT_HANDSHAKING, 0, 0);
+            return new SSLEngineResult(SSLEngineResult.Status.CLOSED, SSLEngineResult.HandshakeStatus.NOT_HANDSHAKING,
+                    0, 0);
         }
 
         // Throw required runtime exceptions
@@ -322,9 +334,8 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
             throw new IllegalArgumentException(sm.getString("engine.nullBuffer"));
         }
         if (offset >= srcs.length || offset + length > srcs.length) {
-            throw new IndexOutOfBoundsException(sm.getString("engine.invalidBufferArray",
-                    Integer.toString(offset), Integer.toString(length),
-                    Integer.toString(srcs.length)));
+            throw new IndexOutOfBoundsException(sm.getString("engine.invalidBufferArray", Integer.toString(offset),
+                    Integer.toString(length), Integer.toString(srcs.length)));
         }
         if (dst.isReadOnly()) {
             throw new ReadOnlyBufferException();
@@ -400,8 +411,8 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
                     // Do we have enough room in dst to write encrypted data?
                     int capacity = dst.remaining();
                     if (capacity < pendingNet) {
-                        return new SSLEngineResult(
-                                SSLEngineResult.Status.BUFFER_OVERFLOW, getHandshakeStatus(), bytesConsumed, bytesProduced);
+                        return new SSLEngineResult(SSLEngineResult.Status.BUFFER_OVERFLOW, getHandshakeStatus(),
+                                bytesConsumed, bytesProduced);
                     }
 
                     // Write the pending data from the network BIO into the dst buffer
@@ -420,10 +431,12 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
     }
 
     @Override
-    public synchronized SSLEngineResult unwrap(final ByteBuffer src, final ByteBuffer[] dsts, final int offset, final int length) throws SSLException {
+    public synchronized SSLEngineResult unwrap(final ByteBuffer src, final ByteBuffer[] dsts, final int offset,
+            final int length) throws SSLException {
         // Check to make sure the engine has not been closed
         if (destroyed) {
-            return new SSLEngineResult(SSLEngineResult.Status.CLOSED, SSLEngineResult.HandshakeStatus.NOT_HANDSHAKING, 0, 0);
+            return new SSLEngineResult(SSLEngineResult.Status.CLOSED, SSLEngineResult.HandshakeStatus.NOT_HANDSHAKING,
+                    0, 0);
         }
 
         // Throw required runtime exceptions
@@ -431,9 +444,8 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
             throw new IllegalArgumentException(sm.getString("engine.nullBuffer"));
         }
         if (offset >= dsts.length || offset + length > dsts.length) {
-            throw new IndexOutOfBoundsException(sm.getString("engine.invalidBufferArray",
-                    Integer.toString(offset), Integer.toString(length),
-                    Integer.toString(dsts.length)));
+            throw new IndexOutOfBoundsException(sm.getString("engine.invalidBufferArray", Integer.toString(offset),
+                    Integer.toString(length), Integer.toString(dsts.length)));
         }
         int capacity = 0;
         final int endOffset = offset + length;
@@ -549,8 +561,7 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
         }
     }
 
-    private int pendingReadableBytesInSSL()
-            throws SSLException {
+    private int pendingReadableBytesInSSL() throws SSLException {
         // NOTE: Calling a fake read is necessary before calling pendingReadableBytesInSSL because
         // SSL_pending will return 0 if OpenSSL has not started the current TLS record
         // See https://www.openssl.org/docs/manmaster/man3/SSL_pending.html
@@ -564,8 +575,7 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
         int pendingReadableBytesInSSL = SSL_pending(state.ssl);
 
         // TLS 1.0 needs additional handling
-        if (Constants.SSL_PROTO_TLSv1.equals(version) && lastPrimingReadResult == 0 &&
-                pendingReadableBytesInSSL == 0) {
+        if (Constants.SSL_PROTO_TLSv1.equals(version) && lastPrimingReadResult == 0 && pendingReadableBytesInSSL == 0) {
             // Perform another priming read
             lastPrimingReadResult = SSL_read(state.ssl, MemorySegment.NULL, 0);
             if (lastPrimingReadResult <= 0) {
@@ -731,56 +741,13 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
 
     @Override
     public synchronized void setEnabledProtocols(String[] protocols) {
-        if (initialized) {
-            return;
-        }
-        if (protocols == null) {
-            // This is correct from the API docs
-            throw new IllegalArgumentException();
-        }
-        if (destroyed) {
-            return;
-        }
-        boolean sslv2 = false;
-        boolean sslv3 = false;
-        boolean tlsv1 = false;
-        boolean tlsv1_1 = false;
-        boolean tlsv1_2 = false;
-        boolean tlsv1_3 = false;
-        for (String p : protocols) {
-            if (!IMPLEMENTED_PROTOCOLS_SET.contains(p)) {
-                throw new IllegalArgumentException(sm.getString("engine.unsupportedProtocol", p));
-            }
-            switch (p) {
-                case Constants.SSL_PROTO_SSLv2 -> sslv2 = true;
-                case Constants.SSL_PROTO_SSLv3 -> sslv3 = true;
-                case Constants.SSL_PROTO_TLSv1 -> tlsv1 = true;
-                case Constants.SSL_PROTO_TLSv1_1 -> tlsv1_1 = true;
-                case Constants.SSL_PROTO_TLSv1_2 -> tlsv1_2 = true;
-                case Constants.SSL_PROTO_TLSv1_3 -> tlsv1_3 = true;
-            }
-        }
+        if(initialized){return;}if(protocols==null){
+        // This is correct from the API docs
+        throw new IllegalArgumentException();}if(destroyed){return;}boolean sslv2=false;boolean sslv3=false;boolean tlsv1=false;boolean tlsv1_1=false;boolean tlsv1_2=false;boolean tlsv1_3=false;for(String p:protocols){if(!IMPLEMENTED_PROTOCOLS_SET.contains(p)){throw new IllegalArgumentException(sm.getString("engine.unsupportedProtocol",p));}switch(p){case Constants.SSL_PROTO_SSLv2->sslv2=true;case Constants.SSL_PROTO_SSLv3->sslv3=true;case Constants.SSL_PROTO_TLSv1->tlsv1=true;case Constants.SSL_PROTO_TLSv1_1->tlsv1_1=true;case Constants.SSL_PROTO_TLSv1_2->tlsv1_2=true;case Constants.SSL_PROTO_TLSv1_3->tlsv1_3=true;}}
         // Enable all and then disable what we not want
-        openssl_h_Compatibility.SSL_set_options(state.ssl, SSL_OP_ALL());
+        openssl_h_Compatibility.SSL_set_options(state.ssl,SSL_OP_ALL());
 
-        if (!sslv2) {
-            openssl_h_Compatibility.SSL_set_options(state.ssl, SSL_OP_NO_SSLv2());
-        }
-        if (!sslv3) {
-            openssl_h_Compatibility.SSL_set_options(state.ssl, SSL_OP_NO_SSLv3());
-        }
-        if (!tlsv1) {
-            openssl_h_Compatibility.SSL_set_options(state.ssl, SSL_OP_NO_TLSv1());
-        }
-        if (!tlsv1_1) {
-            openssl_h_Compatibility.SSL_set_options(state.ssl, SSL_OP_NO_TLSv1_1());
-        }
-        if (!tlsv1_2) {
-            openssl_h_Compatibility.SSL_set_options(state.ssl, SSL_OP_NO_TLSv1_2());
-        }
-        if (!tlsv1_3) {
-            openssl_h_Compatibility.SSL_set_options(state.ssl, SSL_OP_NO_TLSv1_3());
-        }
+        if(!sslv2){openssl_h_Compatibility.SSL_set_options(state.ssl,SSL_OP_NO_SSLv2());}if(!sslv3){openssl_h_Compatibility.SSL_set_options(state.ssl,SSL_OP_NO_SSLv3());}if(!tlsv1){openssl_h_Compatibility.SSL_set_options(state.ssl,SSL_OP_NO_TLSv1());}if(!tlsv1_1){openssl_h_Compatibility.SSL_set_options(state.ssl,SSL_OP_NO_TLSv1_1());}if(!tlsv1_2){openssl_h_Compatibility.SSL_set_options(state.ssl,SSL_OP_NO_TLSv1_2());}if(!tlsv1_3){openssl_h_Compatibility.SSL_set_options(state.ssl,SSL_OP_NO_TLSv1_3());}
     }
 
     @Override
@@ -794,28 +761,29 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
             throw new SSLException(sm.getString("engine.engineClosed"));
         }
         switch (accepted) {
-        case NOT:
-            handshake();
-            accepted = Accepted.EXPLICIT;
-            break;
-        case IMPLICIT:
-            // A user did not start handshake by calling this method by themselves,
-            // but handshake has been started already by wrap() or unwrap() implicitly.
-            // Because it's the user's first time to call this method, it is unfair to
-            // raise an exception.  From the user's standpoint, they never asked for
-            // renegotiation.
+            case NOT:
+                handshake();
+                accepted = Accepted.EXPLICIT;
+                break;
+            case IMPLICIT:
+                // A user did not start handshake by calling this method by themselves,
+                // but handshake has been started already by wrap() or unwrap() implicitly.
+                // Because it's the user's first time to call this method, it is unfair to
+                // raise an exception. From the user's standpoint, they never asked for
+                // renegotiation.
 
-            accepted = Accepted.EXPLICIT; // Next time this method is invoked by the user, we should raise an exception.
-            break;
-        case EXPLICIT:
-            renegotiate();
-            break;
+                accepted = Accepted.EXPLICIT; // Next time this method is invoked by the user, we should raise an
+                                              // exception.
+                break;
+            case EXPLICIT:
+                renegotiate();
+                break;
         }
     }
 
     private byte[] getPeerCertificate() {
         try (var localArena = Arena.ofConfined()) {
-            MemorySegment/*(X509*)*/ x509 = openssl_h_Compatibility.SSL_get_peer_certificate(state.ssl);
+            MemorySegment/* (X509*) */ x509 = openssl_h_Compatibility.SSL_get_peer_certificate(state.ssl);
             MemorySegment bufPointer = localArena.allocateFrom(ValueLayout.ADDRESS, MemorySegment.NULL);
             int length = i2d_X509(x509, bufPointer);
             if (length <= 0) {
@@ -830,7 +798,7 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
     }
 
     private byte[][] getPeerCertChain() {
-        MemorySegment/*STACK_OF(X509)*/ sk = SSL_get_peer_cert_chain(state.ssl);
+        MemorySegment/* STACK_OF(X509) */ sk = SSL_get_peer_cert_chain(state.ssl);
         int len = openssl_h_Compatibility.OPENSSL_sk_num(sk);
         if (len <= 0) {
             return null;
@@ -838,7 +806,7 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
         byte[][] certificateChain = new byte[len][];
         try (var localArena = Arena.ofConfined()) {
             for (int i = 0; i < len; i++) {
-                MemorySegment/*(X509*)*/ x509 = openssl_h_Compatibility.OPENSSL_sk_value(sk, i);
+                MemorySegment/* (X509*) */ x509 = openssl_h_Compatibility.OPENSSL_sk_value(sk, i);
                 MemorySegment bufPointer = localArena.allocateFrom(ValueLayout.ADDRESS, MemorySegment.NULL);
                 int length = i2d_X509(x509, bufPointer);
                 if (length < 0) {
@@ -965,34 +933,24 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
             }
 
             /*
-             * Tomcat Native stores a count of the completed handshakes in the
-             * SSL instance and increments it every time a handshake is
-             * completed. Comparing the handshake count when the handshake
-             * started to the current handshake count enables this code to
-             * detect when the handshake has completed.
+             * Tomcat Native stores a count of the completed handshakes in the SSL instance and increments it every time
+             * a handshake is completed. Comparing the handshake count when the handshake started to the current
+             * handshake count enables this code to detect when the handshake has completed.
              *
-             * Obtaining client certificates after the connection has been
-             * established requires additional checks. We need to trigger
-             * additional reads until the certificates have been read, but we
-             * don't know how many reads we will need as it depends on both
-             * client and network behaviour.
+             * Obtaining client certificates after the connection has been established requires additional checks. We
+             * need to trigger additional reads until the certificates have been read, but we don't know how many reads
+             * we will need as it depends on both client and network behaviour.
              *
-             * The additional reads are triggered by returning NEED_UNWRAP
-             * rather than FINISHED. This allows the standard I/O code to be
-             * used.
+             * The additional reads are triggered by returning NEED_UNWRAP rather than FINISHED. This allows the
+             * standard I/O code to be used.
              *
-             * For TLSv1.2 and below, the handshake completes before the
-             * renegotiation. We therefore use SSL.renegotiatePending() to
-             * check on the current status of the renegotiation and return
-             * NEED_UNWRAP until it completes which means the client
-             * certificates will have been read from the client.
+             * For TLSv1.2 and below, the handshake completes before the renegotiation. We therefore use
+             * SSL.renegotiatePending() to check on the current status of the renegotiation and return NEED_UNWRAP until
+             * it completes which means the client certificates will have been read from the client.
              *
-             * For TLSv1.3, Tomcat Native sets a flag when post handshake
-             * authentication is started and updates it once the client
-             * certificate has been received. We therefore use
-             * SSL.getPostHandshakeAuthInProgress() to check the current status
-             * and return NEED_UNWRAP until that methods indicates that PHA is
-             * no longer in progress.
+             * For TLSv1.3, Tomcat Native sets a flag when post handshake authentication is started and updates it once
+             * the client certificate has been received. We therefore use SSL.getPostHandshakeAuthInProgress() to check
+             * the current status and return NEED_UNWRAP until that methods indicates that PHA is no longer in progress.
              */
 
             // No pending data to be sent to the peer
@@ -1104,7 +1062,7 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
 
     static class VerifyCallback implements SSL_set_verify$callback.Function, SSL_CTX_set_verify$callback.Function {
         @Override
-        public int apply(int preverify_ok, MemorySegment /*X509_STORE_CTX*/ x509ctx) {
+        public int apply(int preverify_ok, MemorySegment /* X509_STORE_CTX */ x509ctx) {
             MemorySegment ssl = X509_STORE_CTX_get_ex_data(x509ctx, SSL_get_ex_data_X509_STORE_CTX_idx());
             EngineState state = getState(ssl);
             if (state == null) {
@@ -1118,34 +1076,31 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
             int errnum = X509_STORE_CTX_get_error(x509ctx);
             int errdepth = X509_STORE_CTX_get_error_depth(x509ctx);
             state.phaState = PHAState.COMPLETE;
-            if (state.certificateVerifyMode == -1 /*SSL_CVERIFY_UNSET*/ || state.certificateVerifyMode == SSL_VERIFY_NONE()) {
+            if (state.certificateVerifyMode == -1 /* SSL_CVERIFY_UNSET */ ||
+                    state.certificateVerifyMode == SSL_VERIFY_NONE()) {
                 return 1;
             }
-            /*SSL_VERIFY_ERROR_IS_OPTIONAL(errnum) -> ((errnum == X509_V_ERR_DEPTH_ZERO_SELF_SIGNED_CERT)
-                || (errnum == X509_V_ERR_SELF_SIGNED_CERT_IN_CHAIN)
-                || (errnum == X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT_LOCALLY)
-                || (errnum == X509_V_ERR_CERT_UNTRUSTED)
-                || (errnum == X509_V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE))*/
-            boolean verifyErrorIsOptional = (errnum == X509_V_ERR_DEPTH_ZERO_SELF_SIGNED_CERT())
-                    || (errnum == X509_V_ERR_SELF_SIGNED_CERT_IN_CHAIN())
-                    || (errnum == X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT_LOCALLY())
-                    || (errnum == X509_V_ERR_CERT_UNTRUSTED())
-                    || (errnum == X509_V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE());
+            /*
+             * SSL_VERIFY_ERROR_IS_OPTIONAL(errnum) -> ((errnum == X509_V_ERR_DEPTH_ZERO_SELF_SIGNED_CERT) || (errnum ==
+             * X509_V_ERR_SELF_SIGNED_CERT_IN_CHAIN) || (errnum == X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT_LOCALLY) ||
+             * (errnum == X509_V_ERR_CERT_UNTRUSTED) || (errnum == X509_V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE))
+             */
+            boolean verifyErrorIsOptional = (errnum == X509_V_ERR_DEPTH_ZERO_SELF_SIGNED_CERT()) ||
+                    (errnum == X509_V_ERR_SELF_SIGNED_CERT_IN_CHAIN()) ||
+                    (errnum == X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT_LOCALLY()) ||
+                    (errnum == X509_V_ERR_CERT_UNTRUSTED()) || (errnum == X509_V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE());
             if (verifyErrorIsOptional && (state.certificateVerifyMode == OpenSSLContext.OPTIONAL_NO_CA)) {
                 ok = 1;
                 openssl_h_Compatibility.SSL_set_verify_result(state.ssl, X509_V_OK());
             }
             /*
-             * Expired certificates vs. "expired" CRLs: by default, OpenSSL
-             * turns X509_V_ERR_CRL_HAS_EXPIRED into a "certificate_expired(45)"
-             * SSL alert, but that's not really the message we should convey to the
-             * peer (at the very least, it's confusing, and in many cases, it's also
-             * inaccurate, as the certificate itself may very well not have expired
-             * yet). We set the X509_STORE_CTX error to something which OpenSSL's
-             * s3_both.c:ssl_verify_alarm_type() maps to SSL_AD_CERTIFICATE_UNKNOWN,
-             * i.e. the peer will receive a "certificate_unknown(46)" alert.
-             * We do not touch errnum, though, so that later on we will still log
-             * the "real" error, as returned by OpenSSL.
+             * Expired certificates vs. "expired" CRLs: by default, OpenSSL turns X509_V_ERR_CRL_HAS_EXPIRED into a
+             * "certificate_expired(45)" SSL alert, but that's not really the message we should convey to the peer (at
+             * the very least, it's confusing, and in many cases, it's also inaccurate, as the certificate itself may
+             * very well not have expired yet). We set the X509_STORE_CTX error to something which OpenSSL's
+             * s3_both.c:ssl_verify_alarm_type() maps to SSL_AD_CERTIFICATE_UNKNOWN, i.e. the peer will receive a
+             * "certificate_unknown(46)" alert. We do not touch errnum, though, so that later on we will still log the
+             * "real" error, as returned by OpenSSL.
              */
             if (ok == 0 && errnum == X509_V_ERR_CRL_HAS_EXPIRED()) {
                 X509_STORE_CTX_set_error(x509ctx, -1);
@@ -1153,9 +1108,9 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
 
             // OCSP
             if (!state.noOcspCheck && (ok > 0)) {
-                /* If there was an optional verification error, it's not
-                 * possible to perform OCSP validation since the issuer may be
-                 * missing/untrusted.  Fail in that case.
+                /*
+                 * If there was an optional verification error, it's not possible to perform OCSP validation since the
+                 * issuer may be missing/untrusted. Fail in that case.
                  */
                 if (verifyErrorIsOptional) {
                     if (state.certificateVerifyMode != OpenSSLContext.OPTIONAL_NO_CA) {
@@ -1185,7 +1140,7 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
         }
     }
 
-    private static int processOCSP(MemorySegment /*X509_STORE_CTX*/ x509ctx) {
+    private static int processOCSP(MemorySegment /* X509_STORE_CTX */ x509ctx) {
         int ocspResponse = V_OCSP_CERTSTATUS_UNKNOWN();
         MemorySegment x509 = X509_STORE_CTX_get_current_cert(x509ctx);
         if (!MemorySegment.NULL.equals(x509)) {
@@ -1208,7 +1163,8 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
                             int length = ASN1_STRING_length(os);
                             MemorySegment data = ASN1_STRING_get0_data(os);
                             // ocsp_urls = decode_OCSP_url(os);
-                            byte[] asn1String = data.reinterpret(length, localArenal, null).toArray(ValueLayout.JAVA_BYTE);
+                            byte[] asn1String =
+                                    data.reinterpret(length, localArenal, null).toArray(ValueLayout.JAVA_BYTE);
                             Asn1Parser parser = new Asn1Parser(asn1String);
                             // Parse the byte sequence
                             ArrayList<String> urls = new ArrayList<>();
@@ -1244,9 +1200,9 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
     }
 
     private static final int ASN1_SEQUENCE = 0x30;
-    private static final int ASN1_OID      = 0x06;
-    private static final int ASN1_STRING   = 0x86;
-    private static final byte[] OCSP_OID = {0x2b, 0x06, 0x01, 0x05, 0x05, 0x07, 0x30, 0x01};
+    private static final int ASN1_OID = 0x06;
+    private static final int ASN1_STRING = 0x86;
+    private static final byte[] OCSP_OID = { 0x2b, 0x06, 0x01, 0x05, 0x05, 0x07, 0x30, 0x01 };
 
     private static void parseOCSPURLs(Asn1Parser parser, ArrayList<String> urls) {
         while (!parser.eof()) {
@@ -1273,7 +1229,7 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
     }
 
     private static int processOCSPRequest(URL url, MemorySegment issuer, MemorySegment x509,
-            MemorySegment /*X509_STORE_CTX*/ x509ctx, Arena localArena) {
+            MemorySegment /* X509_STORE_CTX */ x509ctx, Arena localArena) {
         MemorySegment ocspRequest = MemorySegment.NULL;
         MemorySegment ocspResponse = MemorySegment.NULL;
         MemorySegment id;
@@ -1336,9 +1292,10 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
                         return V_OCSP_CERTSTATUS_UNKNOWN();
                     }
                     // Find by serial number and get the matching response
-                    MemorySegment singleResponse = OCSP_resp_get0(basicResponse, OCSP_resp_find(basicResponse, certId, -1));
-                    return OCSP_single_get0_status(singleResponse, MemorySegment.NULL,
-                            MemorySegment.NULL, MemorySegment.NULL, MemorySegment.NULL);
+                    MemorySegment singleResponse =
+                            OCSP_resp_get0(basicResponse, OCSP_resp_find(basicResponse, certId, -1));
+                    return OCSP_single_get0_status(singleResponse, MemorySegment.NULL, MemorySegment.NULL,
+                            MemorySegment.NULL, MemorySegment.NULL);
                 }
             }
         } catch (Exception e) {
@@ -1376,7 +1333,7 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
     private class OpenSSLSession implements SSLSession {
 
         // lazy init for memory reasons
-        private Map<String, Object> values;
+        private Map<String,Object> values;
 
         // Last accessed time
         private long lastAccessedTime = -1;
@@ -1394,8 +1351,8 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
                         }
                         MemorySegment sessionId = SSL_SESSION_get_id(session, lenPointer);
                         int len = lenPointer.get(ValueLayout.JAVA_INT, 0);
-                        id = (len == 0) ? new byte[0]
-                                : sessionId.reinterpret(len, localArena, null).toArray(ValueLayout.JAVA_BYTE);
+                        id = (len == 0) ? new byte[0] :
+                                sessionId.reinterpret(len, localArena, null).toArray(ValueLayout.JAVA_BYTE);
                     }
                 }
             }
@@ -1446,7 +1403,7 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
             if (value == null) {
                 throw new IllegalArgumentException(sm.getString("engine.nullValue"));
             }
-            Map<String, Object> values = this.values;
+            Map<String,Object> values = this.values;
             if (values == null) {
                 // Use size of 2 to keep the memory overhead small
                 values = this.values = new HashMap<>(2);
@@ -1474,7 +1431,7 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
             if (name == null) {
                 throw new IllegalArgumentException(sm.getString("engine.nullName"));
             }
-            Map<String, Object> values = this.values;
+            Map<String,Object> values = this.values;
             if (values == null) {
                 return;
             }
@@ -1484,7 +1441,7 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
 
         @Override
         public String[] getValueNames() {
-            Map<String, Object> values = this.values;
+            Map<String,Object> values = this.values;
             if (values == null || values.isEmpty()) {
                 return new String[0];
             }
@@ -1510,7 +1467,8 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
                     }
                     chain = getPeerCertChain();
                     if (!clientMode) {
-                        // if used on the server side SSL_get_peer_cert_chain(...) will not include the remote peer certificate.
+                        // if used on the server side SSL_get_peer_cert_chain(...) will not include the remote peer
+                        // certificate.
                         // We use SSL_get_peer_certificate to get it in this case and add it to our array later.
                         // See https://www.openssl.org/docs/ssl/SSL_get_peer_cert_chain.html
                         clientCert = getPeerCertificate();
@@ -1655,17 +1613,15 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
         private int certificateVerifyMode = 0;
         private int handshakeCount = 0;
 
-        private EngineState(MemorySegment ssl, MemorySegment networkBIO,
-                int certificateVerificationDepth, boolean noOcspCheck) {
+        private EngineState(MemorySegment ssl, MemorySegment networkBIO, int certificateVerificationDepth,
+                boolean noOcspCheck) {
             states.put(Long.valueOf(ssl.address()), this);
             this.certificateVerificationDepth = certificateVerificationDepth;
             this.noOcspCheck = noOcspCheck;
             // Use another arena to avoid keeping a reference through segments
             // This also allows making further accesses to the main pointers safer
-            this.ssl = ssl.reinterpret(ValueLayout.ADDRESS.byteSize(), stateArena,
-                openssl_h::SSL_free);
-            this.networkBIO = networkBIO.reinterpret(ValueLayout.ADDRESS.byteSize(), stateArena,
-                openssl_h::BIO_free);
+            this.ssl = ssl.reinterpret(ValueLayout.ADDRESS.byteSize(), stateArena, openssl_h::SSL_free);
+            this.networkBIO = networkBIO.reinterpret(ValueLayout.ADDRESS.byteSize(), stateArena, openssl_h::BIO_free);
         }
 
         @Override
